@@ -159,6 +159,12 @@ class Country(PlaceRecord):
 
       :type: int
 
+    .. attribute:: is_in_european_union
+
+      This is true if the country is a member state of the European Union.
+
+      :type: bool
+
     .. attribute:: iso_code
 
       The two-character `ISO 3166-1
@@ -183,7 +189,14 @@ class Country(PlaceRecord):
 
     """
 
-    _valid_attributes = set(['confidence', 'geoname_id', 'iso_code', 'names'])
+    _valid_attributes = set([
+        'confidence', 'geoname_id', 'is_in_european_union', 'iso_code', 'names'
+    ])
+
+    def __init__(self, locales=None, **kwargs):
+        if 'is_in_european_union' not in kwargs:
+            kwargs['is_in_european_union'] = False
+        super(Country, self).__init__(locales, **kwargs)
 
 
 class RepresentedCountry(Country):
@@ -210,6 +223,12 @@ class RepresentedCountry(Country):
 
       :type: int
 
+    .. attribute:: is_in_european_union
+
+      This is true if the country is a member state of the European Union.
+
+      :type: bool
+
     .. attribute:: iso_code
 
       The two-character `ISO 3166-1
@@ -242,8 +261,10 @@ class RepresentedCountry(Country):
 
     """
 
-    _valid_attributes = set(
-        ['confidence', 'geoname_id', 'iso_code', 'names', 'type'])
+    _valid_attributes = set([
+        'confidence', 'geoname_id', 'is_in_european_union', 'iso_code',
+        'names', 'type'
+    ])
 
 
 class Location(Record):
@@ -517,6 +538,13 @@ class Traits(Record):
 
       :type: unicode
 
+    .. attribute:: is_anonymous
+
+      This is true if the IP address belongs to any sort of anonymous network.
+      This attribute is only available from GeoIP2 Precision Insights.
+
+      :type: bool
+
     .. attribute:: is_anonymous_proxy
 
       This is true if the IP is an anonymous
@@ -530,6 +558,20 @@ class Traits(Record):
         <https://www.maxmind.com/en/geoip2-anonymous-ip-database GeoIP2>`_
         instead.
 
+    .. attribute:: is_anonymous_vpn
+
+      This is true if the IP address belongs to an anonymous VPN system.
+      This attribute is only available from GeoIP2 Precision Insights.
+
+      :type: bool
+
+    .. attribute:: is_hosting_provider
+
+      This is true if the IP address belongs to a hosting provider.
+      This attribute is only available from GeoIP2 Precision Insights.
+
+      :type: bool
+
     .. attribute:: is_legitimate_proxy
 
       This attribute is true if MaxMind believes this IP address to be a
@@ -538,6 +580,13 @@ class Traits(Record):
 
       :type: bool
 
+    .. attribute:: is_public_proxy
+
+      This is true if the IP address belongs to a public proxy. This attribute
+      is only available from GeoIP2 Precision Insights.
+
+      :type: bool
+
     .. attribute:: is_satellite_provider
 
       This is true if the IP address is from a satellite provider that
@@ -551,6 +600,13 @@ class Traits(Record):
         output does not provide sufficiently relevant data for us to maintain
         it.
 
+    .. attribute:: is_tor_exit_node
+
+      This is true if the IP address is a Tor exit node.  This attribute is
+      only available from GeoIP2 Precision Insights.
+
+      :type: bool
+
     .. attribute:: isp
 
       The name of the ISP associated with the IP address. This attribute is
@@ -597,15 +653,23 @@ class Traits(Record):
 
     _valid_attributes = set([
         'autonomous_system_number', 'autonomous_system_organization',
-        'connection_type', 'domain', 'is_anonymous_proxy',
-        'is_legitimate_proxy', 'is_satellite_provider', 'isp', 'ip_address',
-        'organization', 'user_type'
+        'connection_type', 'domain', 'is_anonymous', 'is_anonymous_proxy',
+        'is_anonymous_vpn', 'is_hosting_provider', 'is_legitimate_proxy',
+        'is_public_proxy', 'is_satellite_provider', 'is_tor_exit_node',
+        'is_satellite_provider', 'isp', 'ip_address', 'organization',
+        'user_type'
     ])
 
     def __init__(self, **kwargs):
         for k in [
-                'is_anonymous_proxy', 'is_legitimate_proxy',
-                'is_satellite_provider'
+                'is_anonymous',
+                'is_anonymous_proxy',
+                'is_anonymous_vpn',
+                'is_hosting_provider',
+                'is_legitimate_proxy',
+                'is_public_proxy',
+                'is_satellite_provider',
+                'is_tor_exit_node',
         ]:
             kwargs[k] = bool(kwargs.get(k, False))
         super(Traits, self).__init__(**kwargs)
