@@ -79,6 +79,7 @@ class TestModels(unittest.TestCase):
             },
             'represented_country': {
                 'geoname_id': 3,
+                'is_in_european_union': True,
                 'iso_code': 'GB',
                 'names': {
                     'en': 'United Kingdom'
@@ -90,8 +91,13 @@ class TestModels(unittest.TestCase):
                 'autonomous_system_organization': 'AS Organization',
                 'domain': 'example.com',
                 'ip_address': '1.2.3.4',
-                'is_anonymous_proxy': 0,
-                'is_us_military': 1,
+                'is_anonymous': True,
+                'is_anonymous_proxy': True,
+                'is_anonymous_vpn': True,
+                'is_hosting_provider': True,
+                'is_public_proxy': True,
+                'is_satellite_provider': True,
+                'is_tor_exit_node': True,
                 'isp': 'Comcast',
                 'network_speed': 'cable/DSL',
                 'organization': 'Blorg',
@@ -158,17 +164,28 @@ class TestModels(unittest.TestCase):
             r'^geoip2.models.Insights\(\{.*geoname_id.*\}, \[.*en.*\]\)',
             'Insights str representation looks reasonable')
 
-        self.assertEqual(model,
-                         eval(repr(model)), "Insights repr can be eval'd")
+        self.assertEqual(model, eval(repr(model)),
+                         "Insights repr can be eval'd")
 
         self.assertRegex(
             str(model.location), r'^geoip2.records.Location\(.*longitude=.*\)',
             'Location str representation is reasonable')
 
-        self.assertEqual(model.location,
-                         eval(repr(model.location)),
+        self.assertEqual(model.location, eval(repr(model.location)),
                          "Location repr can be eval'd")
 
+        self.assertIs(model.country.is_in_european_union, False)
+        self.assertIs(model.registered_country.is_in_european_union, False)
+        self.assertIs(model.represented_country.is_in_european_union, True)
+
+        self.assertIs(model.traits.is_anonymous, True)
+        self.assertIs(model.traits.is_anonymous_proxy, True)
+        self.assertIs(model.traits.is_anonymous_vpn, True)
+        self.assertIs(model.traits.is_hosting_provider, True)
+        self.assertIs(model.traits.is_public_proxy, True)
+        self.assertIs(model.traits.is_satellite_provider, True)
+        self.assertIs(model.traits.is_tor_exit_node, True)
+
     def test_insights_min(self):
         model = geoip2.models.Insights({'traits': {'ip_address': '5.6.7.8'}})
         self.assertEqual(
